# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('minio')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def minio_access_key(self) -> Optional[str]:
        """
        Minio Access Key
        """
        return __config__.get('minioAccessKey')

    @_builtins.property
    def minio_api_version(self) -> Optional[str]:
        """
        Minio API Version (type: string, options: v2 or v4, default: v4)
        """
        return __config__.get('minioApiVersion')

    @_builtins.property
    def minio_cacert_file(self) -> Optional[str]:
        return __config__.get('minioCacertFile')

    @_builtins.property
    def minio_cert_file(self) -> Optional[str]:
        return __config__.get('minioCertFile')

    @_builtins.property
    def minio_insecure(self) -> Optional[bool]:
        """
        Disable SSL certificate verification (default: false)
        """
        return __config__.get_bool('minioInsecure')

    @_builtins.property
    def minio_key_file(self) -> Optional[str]:
        return __config__.get('minioKeyFile')

    @_builtins.property
    def minio_password(self) -> Optional[str]:
        """
        Minio Password
        """
        return __config__.get('minioPassword')

    @_builtins.property
    def minio_region(self) -> Optional[str]:
        """
        Minio Region (default: us-east-1)
        """
        return __config__.get('minioRegion')

    @_builtins.property
    def minio_secret_key(self) -> Optional[str]:
        """
        Minio Secret Key
        """
        return __config__.get('minioSecretKey')

    @_builtins.property
    def minio_server(self) -> Optional[str]:
        """
        Minio Host and Port
        """
        return __config__.get('minioServer')

    @_builtins.property
    def minio_session_token(self) -> Optional[str]:
        """
        Minio Session Token
        """
        return __config__.get('minioSessionToken')

    @_builtins.property
    def minio_ssl(self) -> Optional[bool]:
        """
        Minio SSL enabled (default: false)
        """
        return __config__.get_bool('minioSsl')

    @_builtins.property
    def minio_user(self) -> Optional[str]:
        """
        Minio User
        """
        return __config__.get('minioUser')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IamServiceAccountArgs', 'IamServiceAccount']

@pulumi.input_type
class IamServiceAccountArgs:
    def __init__(__self__, *,
                 target_user: pulumi.Input[_builtins.str],
                 disable_user: Optional[pulumi.Input[_builtins.bool]] = None,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 update_secret: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a IamServiceAccount resource.
        :param pulumi.Input[_builtins.bool] disable_user: Disable service account
        :param pulumi.Input[_builtins.str] policy: policy of service account
        :param pulumi.Input[_builtins.bool] update_secret: rotate secret key
        """
        pulumi.set(__self__, "target_user", target_user)
        if disable_user is not None:
            pulumi.set(__self__, "disable_user", disable_user)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if update_secret is not None:
            pulumi.set(__self__, "update_secret", update_secret)

    @_builtins.property
    @pulumi.getter(name="targetUser")
    def target_user(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "target_user")

    @target_user.setter
    def target_user(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "target_user", value)

    @_builtins.property
    @pulumi.getter(name="disableUser")
    def disable_user(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable service account
        """
        return pulumi.get(self, "disable_user")

    @disable_user.setter
    def disable_user(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_user", value)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        policy of service account
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy", value)

    @_builtins.property
    @pulumi.getter(name="updateSecret")
    def update_secret(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        rotate secret key
        """
        return pulumi.get(self, "update_secret")

    @update_secret.setter
    def update_secret(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "update_secret", value)


@pulumi.input_type
class _IamServiceAccountState:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_user: Optional[pulumi.Input[_builtins.bool]] = None,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 target_user: Optional[pulumi.Input[_builtins.str]] = None,
                 update_secret: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering IamServiceAccount resources.
        :param pulumi.Input[_builtins.bool] disable_user: Disable service account
        :param pulumi.Input[_builtins.str] policy: policy of service account
        :param pulumi.Input[_builtins.bool] update_secret: rotate secret key
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if disable_user is not None:
            pulumi.set(__self__, "disable_user", disable_user)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_user is not None:
            pulumi.set(__self__, "target_user", target_user)
        if update_secret is not None:
            pulumi.set(__self__, "update_secret", update_secret)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key", value)

    @_builtins.property
    @pulumi.getter(name="disableUser")
    def disable_user(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable service account
        """
        return pulumi.get(self, "disable_user")

    @disable_user.setter
    def disable_user(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_user", value)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        policy of service account
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="targetUser")
    def target_user(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "target_user")

    @target_user.setter
    def target_user(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_user", value)

    @_builtins.property
    @pulumi.getter(name="updateSecret")
    def update_secret(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        rotate secret key
        """
        return pulumi.get(self, "update_secret")

    @update_secret.setter
    def update_secret(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "update_secret", value)


@pulumi.type_token("minio:index/iamServiceAccount:IamServiceAccount")
class IamServiceAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_user: Optional[pulumi.Input[_builtins.bool]] = None,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 target_user: Optional[pulumi.Input[_builtins.str]] = None,
                 update_secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_minio as minio

        test = minio.IamUser("test",
            name="test",
            force_destroy=True,
            tags={
                "tag-key": "tag-value",
            })
        test_service_account = minio.IamServiceAccount("test_service_account", target_user=test.name)
        pulumi.export("minioUser", test_service_account.access_key)
        pulumi.export("minioPassword", test_service_account.secret_key)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_user: Disable service account
        :param pulumi.Input[_builtins.str] policy: policy of service account
        :param pulumi.Input[_builtins.bool] update_secret: rotate secret key
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IamServiceAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_minio as minio

        test = minio.IamUser("test",
            name="test",
            force_destroy=True,
            tags={
                "tag-key": "tag-value",
            })
        test_service_account = minio.IamServiceAccount("test_service_account", target_user=test.name)
        pulumi.export("minioUser", test_service_account.access_key)
        pulumi.export("minioPassword", test_service_account.secret_key)
        ```

        :param str resource_name: The name of the resource.
        :param IamServiceAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamServiceAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_user: Optional[pulumi.Input[_builtins.bool]] = None,
                 policy: Optional[pulumi.Input[_builtins.str]] = None,
                 target_user: Optional[pulumi.Input[_builtins.str]] = None,
                 update_secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamServiceAccountArgs.__new__(IamServiceAccountArgs)

            __props__.__dict__["disable_user"] = disable_user
            __props__.__dict__["policy"] = policy
            if target_user is None and not opts.urn:
                raise TypeError("Missing required property 'target_user'")
            __props__.__dict__["target_user"] = target_user
            __props__.__dict__["update_secret"] = update_secret
            __props__.__dict__["access_key"] = None
            __props__.__dict__["secret_key"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IamServiceAccount, __self__).__init__(
            'minio:index/iamServiceAccount:IamServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key: Optional[pulumi.Input[_builtins.str]] = None,
            disable_user: Optional[pulumi.Input[_builtins.bool]] = None,
            policy: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            target_user: Optional[pulumi.Input[_builtins.str]] = None,
            update_secret: Optional[pulumi.Input[_builtins.bool]] = None) -> 'IamServiceAccount':
        """
        Get an existing IamServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_user: Disable service account
        :param pulumi.Input[_builtins.str] policy: policy of service account
        :param pulumi.Input[_builtins.bool] update_secret: rotate secret key
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IamServiceAccountState.__new__(_IamServiceAccountState)

        __props__.__dict__["access_key"] = access_key
        __props__.__dict__["disable_user"] = disable_user
        __props__.__dict__["policy"] = policy
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["status"] = status
        __props__.__dict__["target_user"] = target_user
        __props__.__dict__["update_secret"] = update_secret
        return IamServiceAccount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "access_key")

    @_builtins.property
    @pulumi.getter(name="disableUser")
    def disable_user(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Disable service account
        """
        return pulumi.get(self, "disable_user")

    @_builtins.property
    @pulumi.getter
    def policy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        policy of service account
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="targetUser")
    def target_user(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "target_user")

    @_builtins.property
    @pulumi.getter(name="updateSecret")
    def update_secret(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        rotate secret key
        """
        return pulumi.get(self, "update_secret")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IamGroupArgs', 'IamGroup']

@pulumi.input_type
class IamGroupArgs:
    def __init__(__self__, *,
                 disable_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IamGroup resource.
        :param pulumi.Input[_builtins.bool] disable_group: Disable group
        """
        if disable_group is not None:
            pulumi.set(__self__, "disable_group", disable_group)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="disableGroup")
    def disable_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable group
        """
        return pulumi.get(self, "disable_group")

    @disable_group.setter
    def disable_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_group", value)

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_destroy", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _IamGroupState:
    def __init__(__self__, *,
                 disable_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IamGroup resources.
        :param pulumi.Input[_builtins.bool] disable_group: Disable group
        """
        if disable_group is not None:
            pulumi.set(__self__, "disable_group", disable_group)
        if force_destroy is not None:
            pulumi.set(__self__, "force_destroy", force_destroy)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="disableGroup")
    def disable_group(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable group
        """
        return pulumi.get(self, "disable_group")

    @disable_group.setter
    def disable_group(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_group", value)

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "force_destroy")

    @force_destroy.setter
    def force_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_destroy", value)

    @_builtins.property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("minio:index/iamGroup:IamGroup")
class IamGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_minio as minio

        developer = minio.IamGroup("developer", name="developer")
        pulumi.export("minioUserGroup", developer.group_name)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_group: Disable group
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IamGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_minio as minio

        developer = minio.IamGroup("developer", name="developer")
        pulumi.export("minioUserGroup", developer.group_name)
        ```

        :param str resource_name: The name of the resource.
        :param IamGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IamGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disable_group: Optional[pulumi.Input[_builtins.bool]] = None,
                 force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IamGroupArgs.__new__(IamGroupArgs)

            __props__.__dict__["disable_group"] = disable_group
            __props__.__dict__["force_destroy"] = force_destroy
            __props__.__dict__["name"] = name
            __props__.__dict__["group_name"] = None
        super(IamGroup, __self__).__init__(
            'minio:index/iamGroup:IamGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            disable_group: Optional[pulumi.Input[_builtins.bool]] = None,
            force_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            group_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'IamGroup':
        """
        Get an existing IamGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] disable_group: Disable group
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IamGroupState.__new__(_IamGroupState)

        __props__.__dict__["disable_group"] = disable_group
        __props__.__dict__["force_destroy"] = force_destroy
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["name"] = name
        return IamGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="disableGroup")
    def disable_group(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Disable group
        """
        return pulumi.get(self, "disable_group")

    @_builtins.property
    @pulumi.getter(name="forceDestroy")
    def force_destroy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "force_destroy")

    @_builtins.property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "group_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['S3BucketServerSideEncryptionArgs', 'S3BucketServerSideEncryption']

@pulumi.input_type
class S3BucketServerSideEncryptionArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[_builtins.str],
                 encryption_type: pulumi.Input[_builtins.str],
                 kms_key_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a S3BucketServerSideEncryption resource.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "encryption_type", encryption_type)
        pulumi.set(__self__, "kms_key_id", kms_key_id)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "bucket", value)

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "encryption_type")

    @encryption_type.setter
    def encryption_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "encryption_type", value)

    @_builtins.property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "kms_key_id", value)


@pulumi.input_type
class _S3BucketServerSideEncryptionState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering S3BucketServerSideEncryption resources.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if encryption_type is not None:
            pulumi.set(__self__, "encryption_type", encryption_type)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bucket", value)

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "encryption_type")

    @encryption_type.setter
    def encryption_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encryption_type", value)

    @_builtins.property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kms_key_id", value)


@pulumi.type_token("minio:index/s3BucketServerSideEncryption:S3BucketServerSideEncryption")
class S3BucketServerSideEncryption(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a S3BucketServerSideEncryption resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: S3BucketServerSideEncryptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a S3BucketServerSideEncryption resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param S3BucketServerSideEncryptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(S3BucketServerSideEncryptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[_builtins.str]] = None,
                 encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = S3BucketServerSideEncryptionArgs.__new__(S3BucketServerSideEncryptionArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if encryption_type is None and not opts.urn:
                raise TypeError("Missing required property 'encryption_type'")
            __props__.__dict__["encryption_type"] = encryption_type
            if kms_key_id is None and not opts.urn:
                raise TypeError("Missing required property 'kms_key_id'")
            __props__.__dict__["kms_key_id"] = kms_key_id
        super(S3BucketServerSideEncryption, __self__).__init__(
            'minio:index/s3BucketServerSideEncryption:S3BucketServerSideEncryption',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[_builtins.str]] = None,
            encryption_type: Optional[pulumi.Input[_builtins.str]] = None,
            kms_key_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'S3BucketServerSideEncryption':
        """
        Get an existing S3BucketServerSideEncryption resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _S3BucketServerSideEncryptionState.__new__(_S3BucketServerSideEncryptionState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["encryption_type"] = encryption_type
        __props__.__dict__["kms_key_id"] = kms_key_id
        return S3BucketServerSideEncryption(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "bucket")

    @_builtins.property
    @pulumi.getter(name="encryptionType")
    def encryption_type(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "encryption_type")

    @_builtins.property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "kms_key_id")

